# ACSF1

The dataset is compiled from ACS-F1, the first version of the database of appliance consumption signatures. The dataset contains the power consumption of typical appliances. The recordings are characterized by long idle periods and some high bursts of enery consumption when the appliance is active.

The classes correspond to 10 categories of home appliances: mobile phones (via chargers), coffee machines, computer stations (including monitor), fridges and freezers, Hi-Fi systems (CD players), lamp (CFL), laptops (via chargers), microwave ovens, printers, and televisions (LCD or LED). 

Train size: 100

Test size: 100

Missing value: No

Number of classses: 10

Time series length: 1460

There is nothing to infer from the order of exemplars in the train and test set.

Data created by Gisler, Christophe, et al. (see [1], [2]). Data edited by Patrick Schafer and Ulf Leser (see [3]).

[1] Gisler, Christophe, et al. "Appliance consumption signature database and recognition test protocols." Systems, Signal Processing and their Applications (WoSSPA), 2013 8th International Workshop on. IEEE, 2013.

[2] http://www.wattict.com/web/index.php/databases/acs-f1

[3] Schäfer, Patrick, and Ulf Leser. "Fast and accurate time series classification with weasel." Proceedings of the 2017 ACM on Conference on Information and Knowledge Management. ACM, 2017.